@@ -37,7 +37,7 @@ GROUP_BY_FUNCTIONS = collections.OrderedDict([
     # (Real, []),
     (Boolean, [None, ]),
     (Text, [None]),  # (Text, [None, 'length']),
-    (Timestamp, ['year', 'month', 'yearmonth', 'date']),
+    (Timestamp, ['year', 'month', 'yearmonth', 'date', 'day', 'hour', 'minute', 'second', 'time']),
     # (UUID, []),
     # (Geometry, []),
 ])
@@ -344,7 +344,12 @@ class _WhereExpressionVisitor(Visitor):
 
         # non-sub-query
         else:
-            arguments = [super(_WhereExpressionVisitor, self).visit(argument) for argument in visitable.arguments]
+            arguments = []
+            for type_, argument in zip(visitable.prototype.argument_types, visitable.arguments):
+                where = super(_WhereExpressionVisitor, self).visit(argument)
+                if isinstance(argument, Literal) and argument.type is UUID and type_ is Boolean:
+                    where = ("(uuid = %s)" % where)
+                arguments.append(where)
             sql_expr = rewriter_func(*arguments)
 
             # SQL-improved NULL checking (e.g., field != "blah" also matches NULL)
