@@ -50,7 +50,7 @@ def download_http_oath2(url, target_dir, credentials, timeout=60):
         r.raise_for_status()
         local_file = os.path.join(target_dir, os.path.basename(urlparse(r.url).path))
         if "Content-Disposition" in r.headers.keys():
-            matches = re.findall("filename=\"([^\"]+)\"", r.headers["Content-Disposition"])
+            matches = re.findall("filename=\"?([^\"]+)\"?", r.headers["Content-Disposition"])
             if len(matches) > 0:
                 local_file = os.path.join(target_dir, matches[-1])
         with open(local_file, 'wb') as output:
@@ -71,7 +71,7 @@ def download_http(url, target_dir, credentials=None, timeout=60):
         r.raise_for_status()
         local_file = os.path.join(target_dir, os.path.basename(urlparse(r.url).path))
         if "Content-Disposition" in r.headers.keys():
-            matches = re.findall("filename=\"([^\"]+)\"", r.headers["Content-Disposition"])
+            matches = re.findall("filename=\"?([^\"]+)\"?", r.headers["Content-Disposition"])
             if len(matches) > 0:
                 local_file = os.path.join(target_dir, matches[-1])
         with open(local_file, 'wb') as output:
