@@ -9,6 +9,7 @@ import logging
 import os
 import sys
 import tarfile
+import time
 import unittest
 
 PY3 = sys.version_info[0] == 3
@@ -158,6 +159,9 @@ def use_enclosing_directory(request):
 
 @pytest.fixture
 def archive(database, storage, use_enclosing_directory, archive_path):
+    database, _, database_options = database.partition(':')
+
+    # create my_arch.cfg by combining my_arch.cfg.template and test.cfg
     template = open('my_arch.cfg.template', 'r').read()
     data = template.replace('{database}', database)
     data = data.replace('{storage}', storage)
@@ -167,17 +171,27 @@ def archive(database, storage, use_enclosing_directory, archive_path):
         for line in open('test.cfg'):
             if line.startswith('['):
                 section = line.strip()
+            elif '=' in line and section in ('[sqlite]', '[postgresql]') and database_options:
+                key, _, value = line.partition('=')
+                key, value = key.strip(), value.strip()
+                for option in database_options.split(','):
+                    opt_key, opt_value = option.split('=')
+                    if opt_key == key:
+                        line = '%s = %s\n' % (opt_key, opt_value)
             if section != '[DEFAULT]':
                 f.write(line)
 
+    # create product type extension from template
     template = open('product_type.py.template', 'r').read()
     data = template.replace('{archive_path}', archive_path)
     data = data.replace('{use_enclosing_directory}', str(use_enclosing_directory))  # TODO jinja?
     open('product_type.py', 'w').write(data)
 
-    # refresh product type
+    # refresh product type, hook extension
     if 'product_type' in sys.modules:
         del sys.modules['product_type']
+    if 'hook_extension' in sys.modules:
+        del sys.modules['hook_extension']
     os.system('rm *.pyc -f')
 
     # create clean archive
@@ -387,6 +401,26 @@ class TestArchive:
         if archive._params['storage'] == 'fs':
             self._ingest_file(archive, use_symlinks=True, intra=True)
 
+    def test_reingest(self, archive):
+        if archive._params['storage'] == 'fs':
+            # ingest once
+            properties = archive.ingest(['data/pi.txt'])
+
+            # force reingest
+            product_path = archive.product_path(properties)
+            properties = archive.ingest(['data/pi.txt'], force=True)
+            assert os.path.exists(product_path)
+
+            # reingest without force, should raise unique constraint error
+            with pytest.raises(muninn.exceptions.Error) as excinfo:
+                properties = archive.ingest(['data/pi.txt'])
+            assert 'unique constraint' in str(excinfo).lower()
+
+            # force reingest _from archive_ (should not remove product!)
+            product_path = archive.product_path(properties)
+            properties = archive.ingest(product_path, force=True)
+            assert os.path.exists(product_path)
+
     def test_remove_file(self, archive):
         self._ingest_file(archive)
         archive.remove()
@@ -478,6 +512,10 @@ class TestArchive:
         s = archive.search('%s' % uuid)
         assert len(s) == 1
 
+        # use uuid as boolean
+        s = archive.search('%s and product_name == "pi.txt"' % uuid)
+        assert len(s) == 1
+
     def test_tags(self, archive):
         properties = self._ingest_file(archive)
         uuid = properties.core.uuid
@@ -733,6 +771,46 @@ class TestArchive:
         properties = self._pull(archive)
         archive.rebuild_pull_properties(properties.core.uuid, verify_hash=True)
 
+    def test_summary(self, archive):
+        product1 = archive.ingest(['data/a.txt'])
+        year = product1.core.archive_date.year
+        time.sleep(1) # different dates
+        product2 = archive.ingest(['data/b.txt'])
+
+        # default summary (count all)
+        data, headers = archive.summary()
+        assert headers == ['count']
+        assert data == [(2,)] or data == [[2]] # TODO pg8000 gives list per row??
+
+        # aggregate size.sum
+        data, headers = archive.summary(aggregates=['core.size.sum']) # TODO doesn't work without core prefix
+        assert headers == ['count', 'core.size.sum']
+        assert data == [(2, 2030)] or data == [[2, 2030]]
+
+        # group by archive date plus subscript
+        for subscript in [
+            'year',
+            'month',
+            'yearmonth',
+            'date',
+            'day',
+            'hour',
+            'minute',
+            'second',
+            'time',
+        ]:
+            data, headers = archive.summary(group_by=['core.archive_date.' + subscript])
+
+            if subscript == 'year':
+                assert headers == ['core.archive_date.year', 'count']
+                assert data == [(str(year), 2)] or data == [[str(year), 2]]
+
+            elif subscript == 'second':
+                assert headers == ['core.archive_date.second', 'count']
+                assert len(data) == 2
+                assert data[0][0] != data[1][0]
+                assert data[0][1] == data[1][1] == 1
+
 
 class TestQuery:
     def _prep_data(self, archive):
